package com.yanzhu.jh.project.service;

import java.util.List;
import com.yanzhu.jh.project.domain.SurProjectWorkAttendance;

/**
 * 项目出勤Service接口
 * 
 * @author JiangYuQi
 * @date 2023-08-09
 */
public interface ISurProjectWorkAttendanceService 
{
    /**
     * 查询项目出勤
     * 
     * @param id 项目出勤主键
     * @return 项目出勤
     */
    public SurProjectWorkAttendance selectSurProjectWorkAttendanceById(Long id);

    /**
     * 查询项目出勤列表
     * 
     * @param surProjectWorkAttendance 项目出勤
     * @return 项目出勤集合
     */
    public List<SurProjectWorkAttendance> selectSurProjectWorkAttendanceList(SurProjectWorkAttendance surProjectWorkAttendance);

    /**
     * 查询项目出勤列表
     *
     * @param surProjectWorkAttendance 项目出勤
     * @return 项目出勤集合
     */
    public List<SurProjectWorkAttendance> selectBgscreenWorkAttendanceList(SurProjectWorkAttendance surProjectWorkAttendance);

    /**
     * 新增项目出勤
     * 
     * @param surProjectWorkAttendance 项目出勤
     * @return 结果
     */
    public int insertSurProjectWorkAttendance(SurProjectWorkAttendance surProjectWorkAttendance);

    /**
     * 修改项目出勤
     * 
     * @param surProjectWorkAttendance 项目出勤
     * @return 结果
     */
    public int updateSurProjectWorkAttendance(SurProjectWorkAttendance surProjectWorkAttendance);

    /**
     * 批量删除项目出勤
     * 
     * @param ids 需要删除的项目出勤主键集合
     * @return 结果
     */
    public int deleteSurProjectWorkAttendanceByIds(Long[] ids);

    /**
     * 删除项目出勤信息
     * 
     * @param id 项目出勤主键
     * @return 结果
     */
    public int deleteSurProjectWorkAttendanceById(Long id);

    public List<SurProjectWorkAttendance> selectByDate(SurProjectWorkAttendance surProjectWorkAttendance);
}
